<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:exsl="http://exslt.org/common"
	extension-element-prefixes="exsl" 
	>
<xsl:import href="layout.xsl"/>

<xsl:template name="title">
<xsl:choose>
	<xsl:when test="data/@action = 'ShowStat'">IP-статистика</xsl:when>
	<xsl:when test="data/@action = 'GateControl'">Управление шлюзом</xsl:when>
</xsl:choose>
</xsl:template>

<xsl:template match="/data">
<xsl:choose>
	<xsl:when test="@action = 'ShowStat'">
		<xsl:call-template name="ShowStat"/>
	</xsl:when>
	<xsl:when test="@action = 'GateControl'">
	 	<xsl:call-template name="GateControl"/>
	</xsl:when>
</xsl:choose>
</xsl:template>

<xsl:template name="ShowStat">
	<form method='post' action='webexecuter'>
		<xsl:call-template name="action"/>

		<xsl:call-template name="error"/>

		<table class="filter" cellpadding="0" cellspacing="0">
			<tr>
				<td colspan="2">
					<xsl:call-template name="dayFilterForm"/>
				</td>
			</tr>
			<tr>
				<th>Услуги</th>
				<th>Адреса</th>
			</tr>
			<tr>
				<td id="idTdServicesFilter">
					<select size='10' name='services' multiple='1'>
						<xsl:for-each select="services/service">
							<option>
								<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
								<xsl:if test="@selected = '1'"><xsl:attribute name="selected">1</xsl:attribute></xsl:if>
								<xsl:value-of select="@title"/>
							</option>
						</xsl:for-each>
					</select>
				</td>
				<td id="idTdAddressFilter">
					<select size='10' name='addreses' multiple='1'>
						<xsl:for-each select="addreses/address">
							<option>
								<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
								<xsl:if test="@selected = '1'"><xsl:attribute name="selected">1</xsl:attribute></xsl:if>
								<xsl:value-of select="@title"/>
							</option>
						</xsl:for-each>
					</select>
				</td>
			</tr>
			<tr>
				<td colspan="2">
					<em class='comment'>Для выделения сразу нескольких услуг/адресов держите нажатой клавишу 'Ctrl'</em>
				</td>
			</tr>
		</table>
	</form>



	<!-- столбики значений -->
	<xsl:variable name="max">
		<xsl:for-each select="/data/more/service/stat/item/@value">
			<xsl:sort data-type="number" order="descending" />
			<xsl:if test="position() = 1">
				<xsl:value-of select="number(.)"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:variable>

	<!-- создаем новую переменую с node-set <svc @id="33" title="xxx"/> для тех sid для которых рисуем графики + копируем туда labels и данные -->
	<xsl:variable name="active">
		<xsl:for-each select="more/service">
			<xsl:variable name="sid" select="@id"/>
			<!-- проверяем что есть вообще трафик для этого сервиса -->
			<xsl:variable name="localmax">  
				<xsl:for-each select="stat/item/@value">
					<xsl:sort data-type="number" order="descending" />
					<xsl:if test="position() = 1">
						<xsl:value-of select="number(.)"/>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<!-- трафик есть если максим знач больше 0 -->
			<xsl:if test="$localmax > 0">
				<svc>
					<xsl:attribute name="id"><xsl:value-of select="$sid"/></xsl:attribute>
					<xsl:attribute name="title"><xsl:value-of select="/data/services/service[@value=$sid]/@title"/></xsl:attribute>
					<xsl:copy-of select="/data/more/service[@id=$sid]/stat"/>
				</svc>
			</xsl:if>
		</xsl:for-each>
		<xsl:copy-of select="/data/labels"/>
	</xsl:variable>

	<xsl:choose>
		<xsl:when test="count(exsl:node-set($active)/svc) > 0">
			<img width="600" height="300">
				<xsl:attribute name="src">
					<xsl:text>http://chart.apis.google.com/chart?cht=lc&amp;chs=600x300&amp;chd=t:</xsl:text>
					<xsl:for-each select="exsl:node-set($active)/svc">
						<xsl:variable name="sid" select="@id"/>
						<xsl:if test="position() > 1"><xsl:text>|</xsl:text></xsl:if>

						<xsl:for-each select="//label">
							<xsl:if test="position() > 1"><xsl:text>,</xsl:text></xsl:if>
							<xsl:variable name="id" select="@id"/>
							<xsl:variable name="value" select="round(/svc[@id=$sid]/stat/item[@id=$id]/@value * 1000 div $max) div 10"/>
							<xsl:choose>
								<xsl:when test="$value"><xsl:value-of select="$value"/></xsl:when>
								<xsl:otherwise><xsl:text>-1</xsl:text></xsl:otherwise>
							</xsl:choose>
						</xsl:for-each>
					</xsl:for-each>
					<xsl:text>&amp;chxl=0:</xsl:text>
					<xsl:for-each select="/data/labels/label">
						<xsl:text>|</xsl:text><xsl:value-of select="@text"/>
					</xsl:for-each>
					<xsl:variable name="yaxis" select="$max div 1024 div 1024"/>
					<xsl:if test="$yaxis > 1024*2"><xsl:variable name="yaxis" select="$yaxis div 1024"/></xsl:if>
					<xsl:if test="$yaxis > 1024*2"><xsl:variable name="yaxis" select="$yaxis div 1024"/></xsl:if>
					<xsl:text>&amp;chxt=x,y</xsl:text>
					<xsl:text>&amp;chxr=1,0,</xsl:text><xsl:value-of select="$yaxis"/>
					<xsl:text>&amp;chls=3,1,0|3,1,0|3,1,0|3,1,0|3,1,0|3,1,0|3,1,0</xsl:text>
					<xsl:text>&amp;chg=</xsl:text><xsl:value-of select="200.0 div (count(/data/labels/label)-1)"/><xsl:text>,</xsl:text><xsl:value-of select="20"/>
					<xsl:text>&amp;chco=0038AA,AA3800,AA8200,5571AA,AA7155,AA9655,808EAA,AA8E80,AAA080</xsl:text>
					<xsl:text>&amp;chdl=</xsl:text>
					<xsl:for-each select="exsl:node-set($active)/svc">
						<xsl:if test="position() > 1"><xsl:text>|</xsl:text></xsl:if>
						<xsl:value-of select="@title"/>
					</xsl:for-each>
					<xsl:text>&amp;chdlp=b</xsl:text>
				</xsl:attribute>
			</img>

			<br/>
			<br/>

			<!-- нижняя табличка -->
			<strong>Итого: <xsl:value-of select="format-number( /data/stat/@all, '###,###,###,##0')"/>&#160;(&#160;<xsl:value-of select="format-number( /data/stat/@all div 1048576, '###,###,###,##0')"/>&#160;Мбайт&#160;)</strong>
			<table id="idIpnStatTable" cellspacing="1" class="table">
				<thead>
					<tr>
						<th> </th>
						<xsl:for-each select="exsl:node-set($active)/svc">
							<td><xsl:value-of select="@title"/></td>
						</xsl:for-each>
					</tr>
				</thead>
				<tbody>
					<xsl:for-each select="/data/labels/label">
						<xsl:variable name="id" select="@id"/>
						<tr>
							<th><xsl:value-of select="@text"/></th>
							<xsl:for-each select="exsl:node-set($active)/svc">
								<xsl:variable name="sid" select="@id"/>
								<xsl:variable name="value" select="/svc[@id=$sid]/stat/item[@id=$id]/@value"/>
								<td>
									<xsl:choose>
										<xsl:when test="$value"><xsl:value-of select="format-number( $value, '###,###,###,##0')"/></xsl:when>
										<xsl:otherwise><xsl:text>0</xsl:text></xsl:otherwise>
									</xsl:choose>
								</td>
							</xsl:for-each>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>

			<br />
			<xsl:choose>
				<xsl:when test="createDetail/@created='1'">
					<table cellspacing="0" class="filter">
						<tr>
							<th>Отправка детализации поставлена в очередь.
							</th>
						</tr>
					</table>
				</xsl:when>
				<xsl:when test="date/@day='0'">
					<table cellspacing="0" class="filter">
						<tr>
							<th>Выберите день для получения детализации.
							</th>
						</tr>
					</table>
				</xsl:when>
				<xsl:otherwise>
					<form method='post' action='webexecuter'>
						<xsl:call-template name="action"/>
						<input type="hidden" name="createDetail" value="1"/>
						<div style="display:none">
							<xsl:call-template name="dayFilterForm"/>
							<select size='10' name='services' multiple='1'>
								<xsl:for-each select="services/service">
									<option>
										<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
										<xsl:if test="@selected = '1'"><xsl:attribute name="selected">1</xsl:attribute></xsl:if>
										<xsl:value-of select="@title"/>
									</option>
								</xsl:for-each>
							</select>
							<select size='10' name='addreses' multiple='1'>
								<xsl:for-each select="addreses/address">
									<option>
										<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
										<xsl:if test="@selected = '1'"><xsl:attribute name="selected">1</xsl:attribute></xsl:if>
										<xsl:value-of select="@title"/>
									</option>
								</xsl:for-each>
							</select>
						</div>

						<table cellspacing="0" class="filter">
							<tr>
								<th colspan="2">Выслать детализацию для адресов:

									<select name='address_id' style="margin-right:0px;">
										<xsl:for-each select="addreses/address">
											<option>
												<xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
												<xsl:if test="@selected = '1'"><xsl:attribute name="selected">1</xsl:attribute></xsl:if>
												<xsl:value-of select="@title"/>
											</option>
										</xsl:for-each>
									</select>
								</th>
							</tr>
							<tr>
								<th>за час:
									<input type="text" name="hour" size="4" class="filter"></input>
									на email:
									<input type="text" name="mail" size="30" class="filter"></input>
								</th>
								<th>
									<xsl:call-template name="submit">
										<xsl:with-param name="title">Выслать</xsl:with-param>
									</xsl:call-template>
								</th>
							</tr>
						</table>

					</form>
				</xsl:otherwise>
			</xsl:choose>

		</xsl:when>
		<xsl:otherwise>
			<br/>
			Нет данных
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>


<xsl:template name="GateControl">
	<form method='post' action='webexecuter'>
	<xsl:call-template name="action"/>

	<xsl:call-template name="error"/>
	
	<xsl:if test="gate/@status = 2">
		<xsl:call-template name="error">
			<xsl:with-param name="text">
				Сумму долга смотрите в разделе "Отчет по платежам и расходам"
			</xsl:with-param>
		</xsl:call-template>
	</xsl:if>

	<table border='0' cellspacing='0' class="filter">
	  <tr>
		<th nowrap='1'>Текущее состояние шлюза:</th>
		<td>
			<select name='status'>
			<xsl:choose>
				<xsl:when test="gate/@status &lt; 2">
					<option value='0'><xsl:if test="gate/@status = '0'"><xsl:attribute name="selected">1</xsl:attribute></xsl:if>открыт</option>
					<option value='1'><xsl:if test="gate/@status = '1'"><xsl:attribute name="selected">1</xsl:attribute></xsl:if>закрыт</option>
				</xsl:when>
				<xsl:otherwise>
					<option value='2'>заблокирован</option>
				</xsl:otherwise>
			</xsl:choose>
			</select>
		</td>
		<td>
			<xsl:call-template name="submit"/>
		</td>
	 </tr>
	</table>
	
	<div class="report">
	<table cellspacing='1' id="idTableIpnGateControl">
	<col class="col1"/>
	<col class="col2"/>
	<col class="col3"/>
	<col class="col4"/>
	<thead>
	  <tr>
		<td nowrap='1'>Дата и время</td>
		<td>Действие</td>
		<td>Исполнитель</td>
		<td>Комментарий</td>
	  </tr>
	</thead>
	<tbody>
	<xsl:for-each select="gate/row">
		<xsl:if test="position() &lt; 11">
		<tr>
			<td><xsl:value-of select="@dt"/></td>
			<td>
			<xsl:choose>
				<xsl:when test="@action = 0">открыт</xsl:when>
				<xsl:when test="@action = 1">закрыт</xsl:when>
				<xsl:when test="@action = 2">заблокирован</xsl:when>
				<xsl:when test="@action = 3">удален</xsl:when>
				<xsl:when test="@action = 4">жестко блокирован</xsl:when>
				<xsl:otherwise>???</xsl:otherwise>
			</xsl:choose>
			</td>
			<td>
				<xsl:choose>
					<xsl:when test="@uid = -1">клиент</xsl:when>
					<xsl:when test="@uid = 0">сервер</xsl:when>
					<xsl:when test="@uid &gt; 0">админ.</xsl:when>
					<xsl:otherwise>???</xsl:otherwise>
				</xsl:choose>
			</td>
			<td><xsl:value-of select="@comment"/></td>
		</tr>
		</xsl:if>
	</xsl:for-each>
	</tbody>
	</table>
	</div>
	</form>
</xsl:template>


</xsl:stylesheet>=